==> verttice_ui-0.0.153.tar.gz: lib/src/widgets/themed_widgets/themed_editor/themed_editor.dart <==
// 🎯 Dart imports:
import 'dart:async';
import 'dart:convert';
import 'package:html2md/html2md.dart' as html2md;

// 🐦 Flutter imports:
import 'package:delta_to_html/delta_to_html.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:flutter_quill/flutter_quill.dart' hide Text;
import 'package:pointer_interceptor/pointer_interceptor.dart';
import 'package:provider/provider.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';
import 'editor_universal_ui/themed_editor_embed_builder_web.dart';
import 'files_manager.dart';
// ignore: implementation_imports
import 'package:flutter_quill/src/widgets/embeds/default_embed_builder.dart';

class ThemedEditor extends StatefulWidget {
  final RichTextDocumentModel? document;
  final List<FileModel>? files;
  final String? pathToStoreMedia;
  final bool readonly;
  final bool readonlyScrollable;
  final Future<void> Function({
    required RichTextDocumentModel document,
  })? editorContentCallback;
  final Future<void> Function({
    required List<FileModel> files,
  })? filesDataCallback;
  const ThemedEditor({
    Key? key,
    this.document,
    this.files,
    this.readonly = false,
    this.readonlyScrollable = false,
    this.editorContentCallback,
    this.pathToStoreMedia,
    this.filesDataCallback,
  }) : super(key: key);

  Future<Uint8List?> toImage({
    required BuildContext context,
  }) async {
    if (document?.delta == null) {
      return null;
    }

    try {
      final delta = json.decode(document!.delta!);

      return await createImageSizedFromWidgetWithLoading(
        widget: QuillEditor(
          showCursor: false,
          controller: QuillController(
            document: Document.fromJson(delta),
            selection: const TextSelection.collapsed(offset: 0),
          ),
          scrollController: ScrollController(),
          scrollable: false,
          focusNode: FocusNode(),
          autoFocus: true,
          readOnly: true,
          expands: false,
          enableInteractiveSelection: false,
          padding: const EdgeInsets.all(4),
          embedBuilder: !kIsWeb ? defaultEmbedBuilder : defaultEmbedBuilderWeb,
        ),
        context: context,
      );
    } catch (e) {
      return null;
    }
  }

  @override
  State<ThemedEditor> createState() => _EditorState();
}

class _EditorState extends State<ThemedEditor> {
  RichTextDocumentModel? _document;
  QuillController? _controller;
  List<FileModel>? _files;

  @override
  void initState() {
    super.initState();
    _files = widget.files;
    _document = widget.document;
    if (_document?.delta != null) {
      _controller = QuillController(
        document: Document.fromJson(json.decode(_document!.delta!)),
        selection: const TextSelection.collapsed(offset: 0),
      );
    } else {
      _controller = QuillController.basic();
    }
  }

  @override
  void didUpdateWidget(covariant ThemedEditor oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_files, widget.files)) {
      _files = widget.files;
    }
    if (!const DeepCollectionEquality().equals(_document, widget.document)) {
      _document = widget.document;
      if (_document?.delta != null) {
        _controller = QuillController(
          document: Document.fromJson(json.decode(_document!.delta!)),
          selection: const TextSelection.collapsed(offset: 0),
        );
      } else {
        _controller = QuillController.basic();
      }
    }
  }

  Future<void> _capture() async {
    try {
      final delta = _controller!.document.toDelta().toJson();

      final pngBytes = await ThemedEditor(
        document: RichTextDocumentModel(
          delta: json.encode(delta),
        ),
      ).toImage(context: context);

      if (pngBytes == null) {
        return;
      }
      await Download.memory(data: pngBytes, fileType: VFileType.png);
    } catch (e) {
      debugPrint(e.toString());
    }
  }

  @override
  Widget build(BuildContext context) {
    if (_controller == null) {
      return const Scaffold(body: Center(child: Text('Loading...')));
    }

    return Consumer<VertticeUIState>(
      builder: (
        BuildContext context,
        VertticeUIState value,
        Widget? _,
      ) {
        final quillEditor = QuillEditor(
          showCursor: !widget.readonly,
          controller: _controller!,
          scrollController: ScrollController(),
          scrollable: !widget.readonly || widget.readonlyScrollable,
          focusNode: FocusNode(),
          autoFocus: false,
          readOnly: widget.readonly,
          placeholder: widget.readonly ? null : 'Write here...',
          expands: false,
          enableInteractiveSelection: !widget.readonly,
          padding: const EdgeInsets.all(4),
          embedBuilder: !kIsWeb ? defaultEmbedBuilder : defaultEmbedBuilderWeb,
        );

        if (widget.readonly) {
          return Container(
            padding: const EdgeInsets.all(16),
            child: quillEditor,
          );
        }
        return PointerInterceptor(
          child: Scaffold(
            floatingActionButton: widget.editorContentCallback == null ||
                    _controller == null
                ? null
                : FloatingActionButton(
                    onPressed: () async {
                      final delta = _controller!.document.toDelta();
                      await fullPageDialog(
                        context: context,
                        builder: (BuildContext context) {
                          return Scaffold(
                            appBar: ThemedAppBar(
                              navigateBackButton: true,
                              title:
                                  'Preview, Click on the check button to save',
                              actions: [
                                SaveDataHandler(
                                  future: () async {
                                    final rawDelta = _controller!.document
                                        .toDelta()
                                        .toJson();
                                    final html = DeltaToHTML.encodeJson(
                                      rawDelta,
                                    );
                                    final markdown = html2md.convert(html);
                                    print('delta');
                                    print(rawDelta);
                                    print('html');
                                    print(html);
                                    print('markdown');
                                    print(markdown);
                                    await widget.editorContentCallback!(
                                      document:
                                          (_document ?? RichTextDocumentModel())
                                              .copyWith(
                                        markdown: markdown,
                                        delta: json.encode(
                                          rawDelta,
                                        ),
                                        html: html,
                                      ),
                                    );
                                    print('data saved');
                                  },
                                  navigateBackOnSaved: true,
                                  successMessage: 'Document saved',
                                  failedMessage: 'Failed to save document',
                                ),
                              ],
                            ),
                            body: QuillEditor(
                              showCursor: !widget.readonly,
                              controller: QuillController(
                                document: Document.fromDelta(delta),
                                selection:
                                    const TextSelection.collapsed(offset: 0),
                              ),
                              scrollController: ScrollController(),
                              scrollable: true,
                              focusNode: FocusNode(),
                              autoFocus: false,
                              readOnly: true,
                              placeholder: null,
                              expands: true,
                              enableInteractiveSelection: false,
                              padding: const EdgeInsets.all(4),
                              embedBuilder: !kIsWeb
                                  ? defaultEmbedBuilder
                                  : defaultEmbedBuilderWeb,
                            ),
                          );
                        },
                      );
                    },
                    child: ThemedIcons.check(),
                  ),
            body: SafeArea(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  if (!widget.readonly)
                    SizedBox(
                      height: 60,
                      child: Align(
                        alignment: Alignment.centerLeft,
                        child: QuillToolbar.basic(
                          controller: _controller!,
                          showAlignmentButtons: true,
                          showImageButton: true,
                          showVideoButton: true,
                          multiRowsDisplay: false,
                          customButtons: [
                            QuillCustomButton(
                              icon: ThemedIcons.arrowDown().icon,
                              onTap: () async {
                                await _capture();
                              },
                            ),
                            if (widget.pathToStoreMedia != null &&
                                widget.filesDataCallback != null)
                              QuillCustomButton(
                                icon: ThemedIcons.files().icon,
                                onTap: () async {
                                  await fullPageDialog(
                                    context: context,
                                    builder: (BuildContext context) {
                                      return EditorFileMangerView(
                                        files: _files ?? [],
                                        path: widget.pathToStoreMedia!,
                                        filesDataCallback: ({
                                          required List<FileModel> files,
                                        }) async {
                                          await widget.filesDataCallback!(
                                            files: files,
                                          );
                                        },
                                      );
                                    },
                                  );
                                },
                              ),
                          ],
                        ),
                      ),
                    ),
                  const SizedBox(
                    height: 3,
                  ),
                  Expanded(
                    child: Container(
                      padding: const EdgeInsets.only(left: 16, right: 16),
                      child: quillEditor,
                    ),
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}

==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/themed_widgets/themed_editor/themed_editor.dart <==
// 🎯 Dart imports:
import 'dart:async';
import 'dart:convert';
import 'package:html2md/html2md.dart' as html2md;

// 🐦 Flutter imports:
import 'package:delta_to_html/delta_to_html.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:flutter_quill/flutter_quill.dart' hide Text;
import 'package:pointer_interceptor/pointer_interceptor.dart';
import 'package:provider/provider.dart';
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';
import 'editor_embed_builders_web/themed_editor_embed_builder_web.dart';
import 'files_manager.dart';
// ignore: implementation_imports
import 'package:flutter_quill_extensions/flutter_quill_extensions.dart';

class ThemedEditor extends StatefulWidget {
  final RichTextDocumentModel? document;
  final List<FileModel>? files;
  final String? pathToStoreMedia;
  final bool readonly;
  final bool readonlyScrollable;
  final Future<void> Function({
    required RichTextDocumentModel document,
  })? editorContentCallback;
  final Future<void> Function({
    required List<FileModel> files,
  })? filesDataCallback;
  const ThemedEditor({
    Key? key,
    this.document,
    this.files,
    this.readonly = false,
    this.readonlyScrollable = false,
    this.editorContentCallback,
    this.pathToStoreMedia,
    this.filesDataCallback,
  }) : super(key: key);

  Future<Uint8List?> toImage({
    required BuildContext context,
  }) async {
    if (document?.delta == null) {
      return null;
    }

    try {
      final delta = json.decode(document!.delta!);

      return await createImageSizedFromWidgetWithLoading(
        widget: QuillEditor(
          showCursor: false,
          controller: QuillController(
            document: Document.fromJson(delta),
            selection: const TextSelection.collapsed(offset: 0),
          ),
          scrollController: ScrollController(),
          scrollable: false,
          focusNode: FocusNode(),
          autoFocus: true,
          readOnly: true,
          expands: false,
          enableInteractiveSelection: false,
          padding: const EdgeInsets.all(4),
          embedBuilders:
              !kIsWeb ? FlutterQuillEmbeds.builders() : embedBuilderWeb(),
        ),
        context: context,
      );
    } catch (e) {
      return null;
    }
  }

  @override
  State<ThemedEditor> createState() => _EditorState();
}

class _EditorState extends State<ThemedEditor> {
  RichTextDocumentModel? _document;
  QuillController? _controller;
  List<FileModel>? _files;

  @override
  void initState() {
    super.initState();
    _files = widget.files;
    _document = widget.document;
    if (_document?.delta != null) {
      _controller = QuillController(
        document: Document.fromJson(json.decode(_document!.delta!)),
        selection: const TextSelection.collapsed(offset: 0),
      );
    } else {
      _controller = QuillController.basic();
    }
  }

  @override
  void didUpdateWidget(covariant ThemedEditor oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_files, widget.files)) {
      _files = widget.files;
    }
    if (!const DeepCollectionEquality().equals(_document, widget.document)) {
      _document = widget.document;
      if (_document?.delta != null) {
        _controller = QuillController(
          document: Document.fromJson(json.decode(_document!.delta!)),
          selection: const TextSelection.collapsed(offset: 0),
        );
      } else {
        _controller = QuillController.basic();
      }
    }
  }

  Future<void> _capture() async {
    try {
      final delta = _controller!.document.toDelta().toJson();

      final pngBytes = await ThemedEditor(
        document: RichTextDocumentModel(
          delta: json.encode(delta),
        ),
      ).toImage(context: context);

      if (pngBytes == null) {
        return;
      }
      await Download.memory(data: pngBytes, fileType: VFileType.png);
    } catch (e) {
      debugPrint(e.toString());
    }
  }

  @override
  Widget build(BuildContext context) {
    if (_controller == null) {
      return const Scaffold(body: Center(child: Text('Loading...')));
    }

    return Consumer<VertticeUIState>(
      builder: (
        BuildContext context,
        VertticeUIState value,
        Widget? _,
      ) {
        final quillEditor = QuillEditor(
          showCursor: !widget.readonly,
          controller: _controller!,
          scrollController: ScrollController(),
          scrollable: !widget.readonly || widget.readonlyScrollable,
          focusNode: FocusNode(),
          autoFocus: false,
          readOnly: widget.readonly,
          placeholder: widget.readonly ? null : 'Write here...',
          expands: false,
          enableInteractiveSelection: !widget.readonly,
          padding: const EdgeInsets.all(4),
          embedBuilders:
              !kIsWeb ? FlutterQuillEmbeds.builders() : embedBuilderWeb(),
        );

        if (widget.readonly) {
          return Container(
            padding: const EdgeInsets.all(16),
            child: quillEditor,
          );
        }
        return PointerInterceptor(
          child: Scaffold(
            floatingActionButton: widget.editorContentCallback == null ||
                    _controller == null
                ? null
                : FloatingActionButton(
                    onPressed: () async {
                      final delta = _controller!.document.toDelta();
                      await fullPageDialog(
                        context: context,
                        builder: (BuildContext context) {
                          return Scaffold(
                            appBar: ThemedAppBar(
                              navigateBackButton: true,
                              title:
                                  'Preview, Click on the check button to save',
                              actions: [
                                SaveDataHandler(
                                  future: () async {
                                    final rawDelta = _controller!.document
                                        .toDelta()
                                        .toJson();
                                    final html = DeltaToHTML.encodeJson(
                                      rawDelta,
                                    );
                                    final markdown = html2md.convert(html);
                                    print('delta');
                                    print(rawDelta);
                                    print('html');
                                    print(html);
                                    print('markdown');
                                    print(markdown);
                                    await widget.editorContentCallback!(
                                      document:
                                          (_document ?? RichTextDocumentModel())
                                              .copyWith(
                                        markdown: markdown,
                                        delta: json.encode(
                                          rawDelta,
                                        ),
                                        html: html,
                                      ),
                                    );
                                    print('data saved');
                                  },
                                  navigateBackOnSaved: true,
                                  successMessage: 'Document saved',
                                  failedMessage: 'Failed to save document',
                                ),
                              ],
                            ),
                            body: QuillEditor(
                              showCursor: !widget.readonly,
                              controller: QuillController(
                                document: Document.fromDelta(delta),
                                selection:
                                    const TextSelection.collapsed(offset: 0),
                              ),
                              scrollController: ScrollController(),
                              scrollable: true,
                              focusNode: FocusNode(),
                              autoFocus: false,
                              readOnly: true,
                              placeholder: null,
                              expands: true,
                              enableInteractiveSelection: false,
                              padding: const EdgeInsets.all(4),
                              embedBuilders: !kIsWeb
                                  ? FlutterQuillEmbeds.builders()
                                  : embedBuilderWeb(),
                            ),
                          );
                        },
                      );
                    },
                    child: ThemedIcons.check(),
                  ),
            body: SafeArea(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  if (!widget.readonly)
                    SizedBox(
                      height: 60,
                      child: Align(
                        alignment: Alignment.centerLeft,
                        child: QuillToolbar.basic(
                          controller: _controller!,
                          showAlignmentButtons: true,
                          embedButtons: FlutterQuillEmbeds.buttons(
                            showCameraButton: false,
                          ),
                          multiRowsDisplay: false,
                          customButtons: [
                            QuillCustomButton(
                              icon: ThemedIcons.arrowDown().icon,
                              onTap: () async {
                                await _capture();
                              },
                            ),
                            if (widget.pathToStoreMedia != null &&
                                widget.filesDataCallback != null)
                              QuillCustomButton(
                                icon: ThemedIcons.files().icon,
                                onTap: () async {
                                  await fullPageDialog(
                                    context: context,
                                    builder: (BuildContext context) {
                                      return EditorFileMangerView(
                                        files: _files ?? [],
                                        path: widget.pathToStoreMedia!,
                                        filesDataCallback: ({
                                          required List<FileModel> files,
                                        }) async {
                                          await widget.filesDataCallback!(
                                            files: files,
                                          );
                                        },
                                      );
                                    },
                                  );
                                },
                              ),
                          ],
                        ),
                      ),
                    ),
                  const SizedBox(
                    height: 3,
                  ),
                  Expanded(
                    child: Container(
                      padding: const EdgeInsets.only(left: 16, right: 16),
                      child: quillEditor,
                    ),
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
